@@ -15,13 +15,16 @@ describe 'glance::backend::swift' do
 
     describe 'when default parameters' do
 
+      it { is_expected.to contain_class 'swift::client' }
+
       it 'configures glance-api.conf' do
         is_expected.to contain_glance_api_config('glance_store/default_store').with_value('swift')
-        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_size').with_value('5120')
-        is_expected.to contain_glance_api_config('glance_store/swift_store_container').with_value('glance')
-        is_expected.to contain_glance_api_config('glance_store/swift_store_create_container_on_put').with_value(false)
+        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_chunk_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_container').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/swift_store_endpoint_type').with_value('internalURL')
-        is_expected.to contain_glance_api_config('glance_store/swift_store_region').with_value(nil)
+        is_expected.to contain_glance_api_config('glance_store/swift_store_region').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
         is_expected.to contain_glance_api_config('glance_store/default_swift_reference').with_value('ref1')
         is_expected.to contain_glance_swift_config('ref1/key').with_value('key')
@@ -34,11 +37,11 @@ describe 'glance::backend::swift' do
 
       it 'not configures glance-glare.conf' do
         is_expected.to_not contain_glance_glare_config('glance_store/default_store').with_value('swift')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_large_object_size').with_value('5120')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_container').with_value('glance')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_create_container_on_put').with_value(false)
+        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_container').with_value('<SERVICE DEFAULT>')
+        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_glance_glare_config('glance_store/swift_store_endpoint_type').with_value('internalURL')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_region').with_value(nil)
+        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_region').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_glance_glare_config('glance_store/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
         is_expected.to_not contain_glance_glare_config('glance_store/default_swift_reference').with_value('ref1')
       end
@@ -53,6 +56,7 @@ describe 'glance::backend::swift' do
           :swift_store_auth_project_domain_id  => 'proj_domain',
           :swift_store_auth_user_domain_id     => 'user_domain',
           :swift_store_large_object_size       => '100',
+          :swift_store_large_object_chunk_size => '50',
           :swift_store_auth_address            => '127.0.0.2:8080/v1.0/',
           :swift_store_container               => 'swift',
           :swift_store_create_container_on_put => true,
@@ -67,6 +71,7 @@ describe 'glance::backend::swift' do
         is_expected.to contain_glance_api_config('glance_store/swift_store_container').with_value('swift')
         is_expected.to contain_glance_api_config('glance_store/swift_store_create_container_on_put').with_value(true)
         is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_size').with_value('100')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_chunk_size').with_value('50')
         is_expected.to contain_glance_api_config('glance_store/swift_store_endpoint_type').with_value('publicURL')
         is_expected.to contain_glance_api_config('glance_store/swift_store_region').with_value('RegionTwo')
         is_expected.to contain_glance_api_config('glance_store/default_swift_reference').with_value('swift_creds')
